==> plantuml-1.2021.16.tar.gz: plantuml-1.2021.16/README.md <==
PlantUML
========

[![GitHub Org's stars](https://img.shields.io/github/stars/plantuml)](https://github.com/plantuml/plantuml/stargazers/)
[![GitHub watchers](https://img.shields.io/github/watchers/plantuml/plantuml)](https://github.com/plantuml/plantuml/watchers/)
[![GitHub contributors](https://img.shields.io/github/contributors-anon/plantuml/plantuml?color=blue)](https://github.com/plantuml/plantuml/graphs/contributors)
[![GitHub forks](https://img.shields.io/github/forks/plantuml/plantuml)](https://github.com/plantuml/plantuml/network/)
[![GitHub all releases](https://img.shields.io/sourceforge/dt/plantuml?color=blue)](https://github.com/plantuml/plantuml/releases)

[![online](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/badge)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)
[![rate](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/rate)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)
[![peak](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/rate?peak)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)

[![Release (latest by date)](https://img.shields.io/github/v/release/plantuml/plantuml)](https://github.com/plantuml/plantuml/releases/latest)
[![Release Date](https://img.shields.io/github/release-date/plantuml/plantuml?color=blue)](https://github.com/plantuml/plantuml/releases/latest)
[![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/plantuml/plantuml/latest)](https://github.com/plantuml/plantuml/commits/)

[![Pre-release (latest by date)](https://img.shields.io/github/v/release/plantuml/plantuml?color=chocolate&include_prereleases)](https://github.com/plantuml/plantuml/releases/tag/snapshot)
[![Pre-release Date](https://img.shields.io/github/release-date-pre/plantuml/plantuml?color=chocolate)](https://github.com/plantuml/plantuml/releases/tag/snapshot)
[![GitHub last commit](https://img.shields.io/github/last-commit/plantuml/plantuml?color=chocolate)](https://github.com/plantuml/plantuml/commits/)
[![CI](https://github.com/plantuml/plantuml/actions/workflows/ci.yml/badge.svg?color=chocolate)](https://github.com/plantuml/plantuml/actions/workflows/ci.yml)

Generate UML diagram from textual description

PlantUML is a component that allows to quickly write:

 * [Sequence diagram](http://plantuml.com/sequence-diagram),
 * [Use case diagram](http://plantuml.com/use-case-diagram),
 * [Class diagram](http://plantuml.com/class-diagram),
 * [Object diagram](http://plantuml.com/object-diagram),
 * [Activity diagram](http://plantuml.com/activity-diagram-beta) (here is [the legacy syntax](http://plantuml.com/activity-diagram-legacy)),
 * [Component diagram](http://plantuml.com/component-diagram),
 * [Deployment diagram](http://plantuml.com/deployment-diagram),
 * [State diagram](http://plantuml.com/state-diagram),
 * [Timing diagram](http://plantuml.com/timing-diagram).
 
The following non-UML diagrams are also supported:
 * [JSON data](http://plantuml.com/json)
 * [YAML data](http://plantuml.com/yaml)
 * [Network diagram (nwdiag)](http://plantuml.com/nwdiag)
 * [Wireframe graphical interface or UI mockups (salt)](http://plantuml.com/salt)
 * [Archimate diagram](http://plantuml.com/archimate-diagram)
 * [Specification and Description Language (SDL)](http://plantuml.com/activity-diagram-beta#sdl)
 * [Ditaa diagram](http://plantuml.com/ditaa)
 * [Gantt diagram](http://plantuml.com/gantt-diagram)
 * [MindMap diagram](http://plantuml.com/mindmap-diagram)
 * [Work Breakdown Structure diagram (WBS)](http://plantuml.com/wbs-diagram)
 * [Mathematic with AsciiMath or JLaTeXMath notation](http://plantuml.com/ascii-math)
 * [Entity Relationship diagram (IE/ER)](http://plantuml.com/ie-diagram)

Furthermore:
 * [Hyperlinks and tooltips](http://plantuml.com/link)
 * [Creole](http://plantuml.com/creole): rich text, emoticons, unicode, icons
 * [OpenIconic icons](http://plantuml.com/openiconic)
 * [Sprite icons](http://plantuml.com/sprite)
 * [AsciiMath mathematical expressions](http://plantuml.com/ascii-math)

To know more about PlantUML, please visit https://plantuml.com/

==> plantuml-1.2022.0.tar.gz: plantuml-1.2022.0/README.md <==
PlantUML
========

[![GitHub Sponsors](https://img.shields.io/github/sponsors/plantuml?logo=github)](https://github.com/sponsors/plantuml/)
[![GitHub Org's stars](https://img.shields.io/github/stars/plantuml)](https://github.com/plantuml/plantuml/stargazers/)
[![GitHub watchers](https://img.shields.io/github/watchers/plantuml/plantuml)](https://github.com/plantuml/plantuml/watchers/)
[![GitHub contributors](https://img.shields.io/github/contributors-anon/plantuml/plantuml?color=blue)](https://github.com/plantuml/plantuml/graphs/contributors)
[![GitHub forks](https://img.shields.io/github/forks/plantuml/plantuml)](https://github.com/plantuml/plantuml/network/)
[![GitHub all releases](https://img.shields.io/sourceforge/dt/plantuml?color=blue)](https://github.com/plantuml/plantuml/releases)

[![online](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/badge)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)
[![rate](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/rate)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)
[![peak](https://img.shields.io/endpoint?url=https://www.plantuml.com/plantuml/rate?peak)](https://www.plantuml.com/plantuml/uml/SyfFKj2rKt3CoKnELR1Io4ZDoSa70000)

[![Release (latest by date)](https://img.shields.io/github/v/release/plantuml/plantuml)](https://github.com/plantuml/plantuml/releases/latest)
[![Release Date](https://img.shields.io/github/release-date/plantuml/plantuml?color=blue)](https://github.com/plantuml/plantuml/releases/latest)
[![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/plantuml/plantuml/latest)](https://github.com/plantuml/plantuml/commits/)

[![Pre-release (latest by date)](https://img.shields.io/github/v/release/plantuml/plantuml?color=chocolate&include_prereleases)](https://github.com/plantuml/plantuml/releases/tag/snapshot)
[![Pre-release Date](https://img.shields.io/github/release-date-pre/plantuml/plantuml?color=chocolate)](https://github.com/plantuml/plantuml/releases/tag/snapshot)
[![GitHub last commit](https://img.shields.io/github/last-commit/plantuml/plantuml?color=chocolate)](https://github.com/plantuml/plantuml/commits/)
[![CI](https://github.com/plantuml/plantuml/actions/workflows/ci.yml/badge.svg?color=chocolate)](https://github.com/plantuml/plantuml/actions/workflows/ci.yml)

Generate UML diagram from textual description

[PlantUML is **not** affected by the log4j vulnerability.](https://github.com/plantuml/plantuml/issues/826)

PlantUML is a component that allows to quickly write:

 * [Sequence diagram](http://plantuml.com/sequence-diagram),
 * [Use case diagram](http://plantuml.com/use-case-diagram),
 * [Class diagram](http://plantuml.com/class-diagram),
 * [Object diagram](http://plantuml.com/object-diagram),
 * [Activity diagram](http://plantuml.com/activity-diagram-beta) (here is [the legacy syntax](http://plantuml.com/activity-diagram-legacy)),
 * [Component diagram](http://plantuml.com/component-diagram),
 * [Deployment diagram](http://plantuml.com/deployment-diagram),
 * [State diagram](http://plantuml.com/state-diagram),
 * [Timing diagram](http://plantuml.com/timing-diagram).
 
The following non-UML diagrams are also supported:
 * [JSON data](http://plantuml.com/json)
 * [YAML data](http://plantuml.com/yaml)
 * [Network diagram (nwdiag)](http://plantuml.com/nwdiag)
 * [Wireframe graphical interface or UI mockups (salt)](http://plantuml.com/salt)
 * [Archimate diagram](http://plantuml.com/archimate-diagram)
 * [Specification and Description Language (SDL)](http://plantuml.com/activity-diagram-beta#sdl)
 * [Ditaa diagram](http://plantuml.com/ditaa)
 * [Gantt diagram](http://plantuml.com/gantt-diagram)
 * [MindMap diagram](http://plantuml.com/mindmap-diagram)
 * [Work Breakdown Structure diagram (WBS)](http://plantuml.com/wbs-diagram)
 * [Mathematic with AsciiMath or JLaTeXMath notation](http://plantuml.com/ascii-math)
 * [Entity Relationship diagram (IE/ER)](http://plantuml.com/ie-diagram)

Furthermore:
 * [Hyperlinks and tooltips](http://plantuml.com/link)
 * [Creole](http://plantuml.com/creole): rich text, emoticons, unicode, icons
 * [OpenIconic icons](http://plantuml.com/openiconic)
 * [Sprite icons](http://plantuml.com/sprite)
 * [AsciiMath mathematical expressions](http://plantuml.com/ascii-math)

To know more about PlantUML, please visit https://plantuml.com/
